@@ -6,7 +6,7 @@ package Badge::Depot::Plugin::Cpantesters;
 
 # ABSTRACT: CPAN testers plugin for Badge::Depot
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Moose;
 use namespace::autoclean;
@@ -44,7 +44,7 @@ has base_url => (
     isa => Uri,
     coerce => 1,
     lazy => 1,
-    default => 'https://badgedepot.code301.com',
+    default => 'http://badgedepot.code301.com',
 );
 has custom_image_url => (
     is => 'ro',
@@ -121,8 +121,8 @@ Badge::Depot::Plugin::Cpantesters - CPAN testers plugin for Badge::Depot
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/Csson/p5-Badge-Depot-Plugin-CpanTesters"><img src="https://api.travis-ci.org/Csson/p5-Badge-Depot-Plugin-CpanTesters.svg?branch=master" alt="Travis status" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Badge-Depot-Plugin-Cpantesters-0.0101"><img src="https://badgedepot.code301.com/badge/kwalitee/Badge-Depot-Plugin-Cpantesters/0.0101" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Badge-Depot-Plugin-Cpantesters%200.0101"><img src="https://badgedepot.code301.com/badge/cpantesters/Badge-Depot-Plugin-Cpantesters/0.0101" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Badge-Depot-Plugin-Cpantesters-0.0102"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Badge-Depot-Plugin-Cpantesters/0.0102" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Badge-Depot-Plugin-Cpantesters%200.0102"><img src="http://badgedepot.code301.com/badge/cpantesters/Badge-Depot-Plugin-Cpantesters/0.0102" alt="CPAN Testers result" /></a>
 <img src="https://img.shields.io/badge/coverage-70.6%-red.svg" alt="coverage 70.6%" />
 </p>
 
@@ -130,7 +130,7 @@ Badge::Depot::Plugin::Cpantesters - CPAN testers plugin for Badge::Depot
 
 =head1 VERSION
 
-Version 0.0101, released 2016-02-22.
+Version 0.0102, released 2016-08-11.
 
 =head1 SYNOPSIS
 
@@ -143,7 +143,7 @@ If used standalone:
     print $badge->to_html;
     # prints:
     <a href="http://matrix.cpantesters.org/?dist=The-Dist%200.1002">
-        <img src="https://badgedepot.code301.com/badge/cpantesters/The-Dist/0.1002" alt="CPAN Testers result" />
+        <img src="http://badgedepot.code301.com/badge/cpantesters/The-Dist/0.1002" alt="CPAN Testers result" />
     </a>
 
 If used with L<Pod::Weaver::Section::Badges>, in weaver.ini:
